@@ -32,10 +32,13 @@
 #ifdef _WIN32
 #define VC_EXTRALEAN
 #include <Windows.h>
+#include <io.h>
 #else
 #include <syslog.h>
 #endif
 
+#include <unistd.h>
+
 #include <iostream>
 #include <string>
 #include "ola/Logging.h"
@@ -44,7 +47,7 @@
 /**@private*/
 DEFINE_s_int8(log_level, l, ola::OLA_LOG_WARN, "Set the logging level 0 .. 4.");
 /**@private*/
-DEFINE_bool(syslog, false, "Send to syslog rather than stderr.");
+DEFINE_default_bool(syslog, false, "Send to syslog rather than stderr.");
 
 namespace ola {
 
@@ -77,16 +80,11 @@ void IncrementLogLevel() {
 
 
 bool InitLoggingFromFlags() {
-  LogDestination *destination;
+  log_output output = OLA_LOG_NULL;
   if (FLAGS_syslog) {
-    SyslogDestination *syslog_dest = new SyslogDestination();
-    if (!syslog_dest->Init()) {
-      delete syslog_dest;
-      return false;
-    }
-    destination = syslog_dest;
+    output = OLA_LOG_SYSLOG;
   } else {
-    destination = new StdErrorLogDestination();
+    output = OLA_LOG_STDERR;
   }
 
   log_level log_level = ola::OLA_LOG_WARN;
@@ -112,15 +110,18 @@ bool InitLoggingFromFlags() {
       break;
   }
 
-  InitLogging(log_level, destination);
-  return true;
+  return InitLogging(log_level, output);
 }
 
 
 bool InitLogging(log_level level, log_output output) {
   LogDestination *destination;
   if (output == OLA_LOG_SYSLOG) {
-    SyslogDestination *syslog_dest = new SyslogDestination();
+#ifdef _WIN32
+    SyslogDestination *syslog_dest = new WindowsSyslogDestination();
+#else
+    SyslogDestination *syslog_dest = new UnixSyslogDestination();
+#endif
     if (!syslog_dest->Init()) {
       delete syslog_dest;
       return false;
@@ -180,20 +181,14 @@ void LogLine::Write() {
  * @{
  */
 void StdErrorLogDestination::Write(log_level level, const string &log_line) {
-  std::cerr << log_line;
+  ssize_t bytes = write(STDERR_FILENO, log_line.c_str(), log_line.size());
+  (void) bytes;
   (void) level;
 }
 
-
-SyslogDestination::SyslogDestination()
-    : LogDestination(),
-      m_eventlog(NULL) {
-}
-
-bool SyslogDestination::Init() {
 #ifdef _WIN32
+bool WindowsSyslogDestination::Init() {
   m_eventlog = RegisterEventSourceA(NULL, "OLA");
-#endif
   if (!m_eventlog) {
     printf("Failed to initialize event logging\n");
     return false;
@@ -201,9 +196,7 @@ bool SyslogDestination::Init() {
   return true;
 }
 
-
-void SyslogDestination::Write(log_level level, const string &log_line) {
-#ifdef _WIN32
+void WindowsSyslogDestination::Write(log_level level, const string &log_line) {
   WORD pri;
   const char* strings[1];
   strings[0] = log_line.data();
@@ -233,7 +226,13 @@ void SyslogDestination::Write(log_level level, const string &log_line) {
                0,
                strings,
                NULL);
+}
 #else
+bool UnixSyslogDestination::Init() {
+  return true;
+}
+
+void UnixSyslogDestination::Write(log_level level, const string &log_line) {
   int pri;
   switch (level) {
     case OLA_LOG_FATAL:
@@ -252,7 +251,8 @@ void SyslogDestination::Write(log_level level, const string &log_line) {
       pri = LOG_INFO;
   }
   syslog(pri, "%s", log_line.data());
-#endif
 }
+#endif
+
 }  // namespace  ola
 /**@}*/
