@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Serial.cpp
  * Serial I/O Helper methods.
@@ -20,8 +20,6 @@
 
 #include "ola/io/Serial.h"
 
-#include "ola/Logging.h"
-
 namespace ola {
 namespace io {
 
