@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * CommandPrinter.h
  * Write out RDMCommands in a human-readable format.
@@ -37,7 +37,6 @@ using ola::network::NetworkToHost;
 using std::auto_ptr;
 using std::endl;
 using std::string;
-using std::stringstream;
 
 /**
  * Constructor
