@@ -25,8 +25,7 @@
 #include <string>
 #include <vector>
 #include "common/rdm/FakeNetworkManager.h"
-#include "ola/BaseTypes.h"
-#include "ola/Clock.h"
+#include "ola/Constants.h"
 #include "ola/Logging.h"
 #include "ola/base/Array.h"
 #include "ola/network/IPV4Address.h"
