@@ -167,21 +167,21 @@ typedef enum {
   PID_QUEUED_STATUS_ENDPOINT_COLLECTION = 0x7FD3,
   PID_QUEUED_STATUS_UID_COLLECTION = 0x7FD4,
 
-  // Draft E1.37-2 PIDs - DO NOT USE, values will change
-  PID_LIST_INTERFACES = 0xFFE0,
-  PID_INTERFACE_LABEL = 0xFFE1,
-  PID_INTERFACE_HARDWARE_ADDRESS_TYPE1 = 0xFFE2,
-  PID_IPV4_DHCP_MODE = 0xFFE3,
-  PID_IPV4_ZEROCONF_MODE = 0xFFE4,
-  PID_IPV4_CURRENT_ADDRESS = 0xFFE5,
-  PID_IPV4_STATIC_ADDRESS = 0xFFE6,
-  PID_INTERFACE_RENEW_DHCP = 0xFFE7,
-  PID_INTERFACE_RELEASE_DHCP = 0xFFE8,
-  PID_INTERFACE_APPLY_CONFIGURATION = 0xFFE9,
-  PID_IPV4_DEFAULT_ROUTE = 0xFFEA,
-  PID_DNS_NAME_SERVER = 0xFFEB,
-  PID_DNS_HOSTNAME = 0xFFEC,
-  PID_DNS_DOMAIN_NAME = 0xFFED,
+  // E1.37-2 PIDs
+  PID_LIST_INTERFACES = 0x0700,
+  PID_INTERFACE_LABEL = 0x0701,
+  PID_INTERFACE_HARDWARE_ADDRESS_TYPE1 = 0x0702,
+  PID_IPV4_DHCP_MODE = 0x0703,
+  PID_IPV4_ZEROCONF_MODE = 0x0704,
+  PID_IPV4_CURRENT_ADDRESS = 0x0705,
+  PID_IPV4_STATIC_ADDRESS = 0x0706,
+  PID_INTERFACE_RENEW_DHCP = 0x0707,
+  PID_INTERFACE_RELEASE_DHCP = 0x0708,
+  PID_INTERFACE_APPLY_CONFIGURATION = 0x0709,
+  PID_IPV4_DEFAULT_ROUTE = 0x070A,
+  PID_DNS_NAME_SERVER = 0x070B,
+  PID_DNS_HOSTNAME = 0x070C,
+  PID_DNS_DOMAIN_NAME = 0x070D,
 } rdm_pid;
 
 
@@ -324,7 +324,7 @@ typedef enum {
   NR_PACKET_SIZE_UNSUPPORTED = 0x0008,
   NR_SUB_DEVICE_OUT_OF_RANGE = 0x0009,
   NR_PROXY_BUFFER_FULL = 0x000A,
-  NR_ACTION_NOT_SUPPORTED = 0x0010,
+  NR_ACTION_NOT_SUPPORTED = 0x000B,
   NR_ENDPOINT_NUMBER_INVALID = 0x0011
 } rdm_nack_reason;
 
