@@ -80,8 +80,8 @@ void DNSSDDescriptor::PerformRead() {
 }
 
 BonjourDiscoveryAgent::RegisterArgs::RegisterArgs(
-    const std::string &service_name,
-    const std::string &type,
+    const string &service_name,
+    const string &type,
     uint16_t port,
     const RegisterOptions &options)
     : RegisterOptions(options),
@@ -92,7 +92,7 @@ BonjourDiscoveryAgent::RegisterArgs::RegisterArgs(
 
 BonjourDiscoveryAgent::BonjourDiscoveryAgent()
     : m_thread(new ola::thread::CallbackThread(NewSingleCallback(
-          &m_ss, &ola::io::SelectServer::Run))) {
+          this, &BonjourDiscoveryAgent::RunThread))) {
 }
 
 BonjourDiscoveryAgent::~BonjourDiscoveryAgent() {
@@ -172,4 +172,9 @@ string BonjourDiscoveryAgent::BuildTxtRecord(
   }
   return output;
 }
+
+void BonjourDiscoveryAgent::RunThread() {
+  m_ss.Run();
+  m_ss.DrainCallbacks();
+}
 }  // namespace ola
