@@ -77,6 +77,17 @@ void StartSignalThread(ola::io::SelectServer *ss,
  * Main
  */
 int main(int argc, char *argv[]) {
+  // Take a copy of the arguments otherwise the export map is incorrect.
+  const int original_argc = argc;
+  char *original_argv[original_argc];
+  for (int i = 0; i < original_argc; i++) {
+    original_argv[i] = argv[i];
+  }
+
+  // We don't use the longer form for ServerInit here because we need to check
+  // for root and possibly daemonise before doing the rest of the work from
+  // ServerInit.
+
   ola::SetHelpString("[options]", "Start the OLA Daemon.");
   ola::ParseFlags(&argc, argv);
 
@@ -98,7 +109,7 @@ int main(int argc, char *argv[]) {
 #endif
 
   ola::ExportMap export_map;
-  ola::ServerInit(argc, argv, &export_map);
+  ola::ServerInit(original_argc, original_argv, &export_map);
 
   // We need to block signals before we start any threads.
   // Signal setup is complex. First of all we need to install NULL handlers to
