@@ -27,7 +27,7 @@
 #include <utility>
 #include <vector>
 
-#include "ola/BaseTypes.h"
+#include "ola/Constants.h"
 #include "ola/Logging.h"
 #include "ola/network/IPV4Address.h"
 #include "ola/network/NetworkUtils.h"
@@ -77,117 +77,110 @@ typedef map<UID, std::pair<IPV4Address, uint8_t> > uid_map;
 // Input ports are ones that send data using ArtNet
 class ArtNetNodeImpl::InputPort {
  public:
-    InputPort()
-        : enabled(false),
-          sequence_number(0),
-          discovery_callback(NULL),
-          discovery_timeout(ola::thread::INVALID_TIMEOUT),
-          rdm_request_callback(NULL),
-          pending_request(NULL),
-          rdm_send_timeout(ola::thread::INVALID_TIMEOUT),
-          m_port_address(0),
-          m_tod_callback(NULL) {
+  InputPort()
+      : enabled(false),
+        sequence_number(0),
+        discovery_callback(NULL),
+        discovery_timeout(ola::thread::INVALID_TIMEOUT),
+        rdm_request_callback(NULL),
+        pending_request(NULL),
+        rdm_send_timeout(ola::thread::INVALID_TIMEOUT),
+        m_port_address(0),
+        m_tod_callback(NULL) {
+  }
+  ~InputPort() {}
+
+  // Returns true if the address changed.
+  bool SetUniverseAddress(uint8_t universe_address) {
+    universe_address = universe_address & 0x0f;
+    if ((m_port_address & 0x0f) == universe_address)
+      return false;
+
+    m_port_address = ((m_port_address & 0xf0) | universe_address);
+    uids.clear();
+    subscribed_nodes.clear();
+    return true;
+  }
+
+  void ClearSubscribedNodes() {
+    subscribed_nodes.clear();
+  }
+
+  // Returns true if the address changed.
+  bool SetSubNetAddress(uint8_t subnet_address) {
+    subnet_address = subnet_address << 4;
+    if (subnet_address == (m_port_address & 0xf0))
+      return false;
+
+    m_port_address = subnet_address | (m_port_address & 0x0f);
+    uids.clear();
+    subscribed_nodes.clear();
+    return true;
+  }
+
+  // The 8-bit port address, which is made up of the sub-net and universe
+  // address.
+  uint8_t PortAddress() const {
+    return m_port_address;
+  }
+
+  void SetTodCallback(ola::rdm::RDMDiscoveryCallback *callback) {
+    m_tod_callback.reset(callback);
+  }
+
+  void RunTodCallback() {
+    if (m_tod_callback.get())
+      RunRDMCallbackWithUIDs(uids, m_tod_callback.get());
+  }
+
+  void RunDiscoveryCallback() {
+    if (discovery_callback) {
+      RDMDiscoveryCallback *callback = discovery_callback;
+      discovery_callback = NULL;
+      RunRDMCallbackWithUIDs(uids, callback);
     }
-    ~InputPort() {}
+  }
 
-    // Returns true if the address changed.
-    bool SetUniverseAddress(uint8_t universe_address) {
-      universe_address = universe_address & 0x0f;
-      if ((m_port_address & 0x0f) == universe_address)
-        return false;
+  void IncrementUIDCounts() {
+    for (uid_map::iterator iter = uids.begin(); iter != uids.end(); ++iter)
+      iter->second.second++;
+  }
 
-      m_port_address = ((m_port_address & 0xf0) | universe_address);
-      uids.clear();
-      subscribed_nodes.clear();
-      return true;
-    }
+  bool enabled;
+  uint8_t sequence_number;
+  map<IPV4Address, TimeStamp> subscribed_nodes;
+  uid_map uids;  // used to keep track of the UIDs
+  // NULL if discovery isn't running, otherwise the callback to run when it
+  // finishes
+  ola::rdm::RDMDiscoveryCallback *discovery_callback;
+  // The set of nodes we're expecting a response from
+  set<IPV4Address> discovery_node_set;
+  // the timeout_id for the discovery timer
+  ola::thread::timeout_id discovery_timeout;
+  // the in-flight request and it's callback
+  ola::rdm::RDMCallback *rdm_request_callback;
+  const ola::rdm::RDMRequest *pending_request;
+  IPV4Address rdm_ip_destination;
 
-    void ClearSubscribedNodes() {
-      subscribed_nodes.clear();
-    }
-
-    // Returns true if the address changed.
-    bool SetSubNetAddress(uint8_t subnet_address) {
-      subnet_address = subnet_address << 4;
-      if (subnet_address == (m_port_address & 0xf0))
-        return false;
-
-      m_port_address = subnet_address | (m_port_address & 0x0f);
-      uids.clear();
-      subscribed_nodes.clear();
-      return true;
-    }
-
-    // The 8-bit port address, which is made up of the sub-net and universe
-    // address.
-    uint8_t PortAddress() const {
-      return m_port_address;
-    }
-
-    void SetTodCallback(ola::rdm::RDMDiscoveryCallback *callback) {
-      m_tod_callback.reset(callback);
-    }
-
-    void RunTodCallback() {
-      if (m_tod_callback.get())
-        RunRDMCallbackWithUIDs(uids, m_tod_callback.get());
-    }
-
-    void RunDiscoveryCallback() {
-      if (discovery_callback) {
-        RDMDiscoveryCallback *callback = discovery_callback;
-        discovery_callback = NULL;
-        RunRDMCallbackWithUIDs(uids, callback);
-      }
-    }
-
-    void IncrementUIDCounts() {
-      for (uid_map::iterator iter = uids.begin(); iter != uids.end(); ++iter)
-        iter->second.second++;
-    }
-
-    bool enabled;
-    uint8_t sequence_number;
-    map<IPV4Address, TimeStamp> subscribed_nodes;
-    uid_map uids;  // used to keep track of the UIDs
-    // NULL if discovery isn't running, otherwise the callback to run when it
-    // finishes
-    ola::rdm::RDMDiscoveryCallback *discovery_callback;
-    // The set of nodes we're expecting a response from
-    set<IPV4Address> discovery_node_set;
-    // the timeout_id for the discovery timer
-    ola::thread::timeout_id discovery_timeout;
-    // the in-flight request and it's callback
-    ola::rdm::RDMCallback *rdm_request_callback;
-    const ola::rdm::RDMRequest *pending_request;
-    IPV4Address rdm_ip_destination;
-
-    // these control the sending of RDM requests.
-    ola::thread::timeout_id rdm_send_timeout;
+  // these control the sending of RDM requests.
+  ola::thread::timeout_id rdm_send_timeout;
 
  private:
-    uint8_t m_port_address;
-    // The callback to run if we receive an TOD and the discovery process
-    // isn't running
-    auto_ptr<ola::rdm::RDMDiscoveryCallback> m_tod_callback;
+  uint8_t m_port_address;
+  // The callback to run if we receive an TOD and the discovery process
+  // isn't running
+  auto_ptr<ola::rdm::RDMDiscoveryCallback> m_tod_callback;
 
-    void RunRDMCallbackWithUIDs(const uid_map &uids,
-                                RDMDiscoveryCallback *callback) {
-      UIDSet uid_set;
-      uid_map::const_iterator uid_iter = uids.begin();
-      for (; uid_iter != uids.end(); ++uid_iter)
-        uid_set.AddUID(uid_iter->first);
-      callback->Run(uid_set);
-    }
+  void RunRDMCallbackWithUIDs(const uid_map &uids,
+                              RDMDiscoveryCallback *callback) {
+    UIDSet uid_set;
+    uid_map::const_iterator uid_iter = uids.begin();
+    for (; uid_iter != uids.end(); ++uid_iter)
+      uid_set.AddUID(uid_iter->first);
+    callback->Run(uid_set);
+  }
 };
 
-/*
- * Create a new node
- * @param iface the interface to use.
- * @param short_name the short node name
- * @param long_name the long node name
- * @param subnet_address the ArtNet 'subnet' address, 4 bits.
- */
 ArtNetNodeImpl::ArtNetNodeImpl(const ola::network::Interface &iface,
                                ola::io::SelectServerInterface *ss,
                                const ArtNetNodeOptions &options,
@@ -228,10 +221,6 @@ ArtNetNodeImpl::ArtNetNodeImpl(const ola::network::Interface &iface,
   }
 }
 
-
-/*
- * Cleanup
- */
 ArtNetNodeImpl::~ArtNetNodeImpl() {
   Stop();
 
@@ -249,10 +238,6 @@ ArtNetNodeImpl::~ArtNetNodeImpl() {
   }
 }
 
-
-/*
- * Start this node. The port modifying functions can be called before this.
- */
 bool ArtNetNodeImpl::Start() {
   if (m_running || !InitNetwork())
     return false;
@@ -261,16 +246,12 @@ bool ArtNetNodeImpl::Start() {
   return true;
 }
 
-
-/*
- * Stop this node
- */
 bool ArtNetNodeImpl::Stop() {
   if (!m_running)
     return false;
 
   // clean up any in-flight rdm requests
-  vector<std::string> packets;
+  vector<string> packets;
   InputPorts::iterator iter = m_input_ports.begin();
   for (; iter != m_input_ports.end(); ++iter) {
     InputPort *port = *iter;
@@ -307,11 +288,6 @@ bool ArtNetNodeImpl::Stop() {
   return true;
 }
 
-
-/**
- * Start the configuration transaction.
- * @returns false if there is already a transaction pending.
- */
 bool ArtNetNodeImpl::EnterConfigurationMode() {
   if (m_in_configuration_mode)
     return false;
@@ -321,11 +297,6 @@ bool ArtNetNodeImpl::EnterConfigurationMode() {
   return true;
 }
 
-
-/**
- * End the configuration transaction.
- * @returns false if we weren't in a transaction.
- */
 bool ArtNetNodeImpl::ExitConfigurationMode() {
   if (!m_in_configuration_mode)
     return false;
@@ -342,10 +313,6 @@ bool ArtNetNodeImpl::ExitConfigurationMode() {
   return true;
 }
 
-
-/*
- * Set the short name.
- */
 bool ArtNetNodeImpl::SetShortName(const string &name) {
   if (m_short_name == name)
     return true;
@@ -354,10 +321,6 @@ bool ArtNetNodeImpl::SetShortName(const string &name) {
   return SendPollReplyIfRequired();
 }
 
-
-/*
- * Set the long name.
- */
 bool ArtNetNodeImpl::SetLongName(const string &name) {
   if (m_long_name == name)
     return true;
@@ -365,10 +328,6 @@ bool ArtNetNodeImpl::SetLongName(const string &name) {
   return SendPollReplyIfRequired();
 }
 
-
-/*
- * The the net address for this node
- */
 bool ArtNetNodeImpl::SetNetAddress(uint8_t net_address) {
   if (net_address & 0x80) {
     OLA_WARN << "Artnet net address > 127, truncating";
@@ -391,10 +350,6 @@ bool ArtNetNodeImpl::SetNetAddress(uint8_t net_address) {
   return SendPollReplyIfRequired();
 }
 
-
-/*
- * The the subnet address for this node
- */
 bool ArtNetNodeImpl::SetSubnetAddress(uint8_t subnet_address) {
   // Set for all input ports.
   bool changed = false;
@@ -422,17 +377,10 @@ bool ArtNetNodeImpl::SetSubnetAddress(uint8_t subnet_address) {
   return SendPollReplyIfRequired();
 }
 
-
-/*
- * Return the number of input ports
- */
 uint8_t ArtNetNodeImpl::InputPortCount() const {
   return m_input_ports.size();
 }
 
-/**
- * Set the universe address of an input port
- */
 bool ArtNetNodeImpl::SetInputPortUniverse(uint8_t port_id,
                                           uint8_t universe_id) {
   InputPort *port = GetInputPort(port_id);
@@ -447,19 +395,11 @@ bool ArtNetNodeImpl::SetInputPortUniverse(uint8_t port_id,
   return true;
 }
 
-/**
- * Return the 8bit universe address for a port. This does not include the
- * ArtNet III net-address. Invalid port_ids return 0.
- */
 uint8_t ArtNetNodeImpl::GetInputPortUniverse(uint8_t port_id) const {
   const InputPort *port = GetInputPort(port_id);
   return port ? port->PortAddress() : 0;
 }
 
-
-/*
- * Disable an input port.
- */
 void ArtNetNodeImpl::DisableInputPort(uint8_t port_id) {
   InputPort *port = GetInputPort(port_id);
   bool was_enabled = port->enabled;
@@ -470,22 +410,11 @@ void ArtNetNodeImpl::DisableInputPort(uint8_t port_id) {
     SendPollReplyIfRequired();
 }
 
-
-/*
- * Return the state (enabled or disabled) of an input port. An invalid port_id
- * returns false.
- */
 bool ArtNetNodeImpl::InputPortState(uint8_t port_id) const {
   const InputPort *port = GetInputPort(port_id);
   return port ? port->enabled : false;
 }
 
-
-/*
- * Set the universe for an output port.
- * @param port_id a port id between 0 and ARTNET_MAX_PORTS - 1
- * @param universe_id the new universe id.
- */
 bool ArtNetNodeImpl::SetOutputPortUniverse(uint8_t port_id,
                                            uint8_t universe_id) {
   OutputPort *port = GetOutputPort(port_id);
@@ -501,20 +430,11 @@ bool ArtNetNodeImpl::SetOutputPortUniverse(uint8_t port_id,
   return SendPollReplyIfRequired();
 }
 
-
-/*
- * Return the current universe address for an output port
- * @param port_id a port id between 0 and ARTNET_MAX_PORTS - 1
- */
 uint8_t ArtNetNodeImpl::GetOutputPortUniverse(uint8_t port_id) {
   OutputPort *port = GetOutputPort(port_id);
   return port ? port->universe_address : 0;
 }
 
-
-/*
- * Disable an input port.
- */
 void ArtNetNodeImpl::DisableOutputPort(uint8_t port_id) {
   OutputPort *port = GetOutputPort(port_id);
   bool was_enabled = port->enabled;
@@ -524,20 +444,11 @@ void ArtNetNodeImpl::DisableOutputPort(uint8_t port_id) {
     SendPollReplyIfRequired();
 }
 
-
-/*
- * Return the state (enabled or disabled) of an input port. An invalid port_id
- * returns false.
- */
 bool ArtNetNodeImpl::OutputPortState(uint8_t port_id) const {
   const OutputPort *port = GetOutputPort(port_id);
   return port ? port->enabled : false;
 }
 
-
-/*
- * Set the merge mode for an output port
- */
 bool ArtNetNodeImpl::SetMergeMode(uint8_t port_id,
                                   artnet_merge_mode merge_mode) {
   OutputPort *port = GetOutputPort(port_id);
@@ -548,10 +459,6 @@ bool ArtNetNodeImpl::SetMergeMode(uint8_t port_id,
   return SendPollReplyIfRequired();
 }
 
-
-/*
- * Send an ArtPoll if any of the ports are sending data
- */
 bool ArtNetNodeImpl::SendPoll() {
   if (!m_running)
     return false;
@@ -576,13 +483,6 @@ bool ArtNetNodeImpl::SendPoll() {
   return SendPacket(packet, size, m_interface.bcast_address);
 }
 
-
-/*
- * Send some DMX data
- * @param universe the id of the universe to send
- * @param buffer the DMX data
- * @return true if it was send successfully, false otherwise
- */
 bool ArtNetNodeImpl::SendDMX(uint8_t port_id, const DmxBuffer &buffer) {
   InputPort *port = GetEnabledInputPort(port_id, "ArtDMX");
   if (!port)
@@ -656,13 +556,6 @@ bool ArtNetNodeImpl::SendDMX(uint8_t port_id, const DmxBuffer &buffer) {
   return sent_ok;
 }
 
-
-/*
- * Flush the TOD and force a full discovery.
- * The DiscoverableQueueingRDMController ensures this is only called one at a
- * time.
- * @param port_id port to send on
- */
 void ArtNetNodeImpl::RunFullDiscovery(uint8_t port_id,
                                       RDMDiscoveryCallback *callback) {
   InputPort *port = GetEnabledInputPort(port_id, "ArtTodControl");
@@ -688,15 +581,6 @@ void ArtNetNodeImpl::RunFullDiscovery(uint8_t port_id,
     port->RunDiscoveryCallback();
 }
 
-
-/*
- * Run an 'incremental' discovery. This just involves fetching the TOD from all
- * nodes.
- *
- * The DiscoverableQueueingRDMController ensures only one discovery process is
- * running per port at any time.
- * @param port_id port to send on
- */
 void ArtNetNodeImpl::RunIncrementalDiscovery(
     uint8_t port_id,
     ola::rdm::RDMDiscoveryCallback *callback) {
@@ -724,20 +608,10 @@ void ArtNetNodeImpl::RunIncrementalDiscovery(
     port->RunDiscoveryCallback();
 }
 
-
-/*
- * Send an RDMRequest on this port, this may defer the sending if there are
- * other outstanding messages in the queue.
- * @param port_id the if of the port to send the request on
- * @param request the RDMRequest object
- *
- * Because this is wrapped in the QueueingRDMController this will only be
- * called one-at-a-time (per port)
- */
 void ArtNetNodeImpl::SendRDMRequest(uint8_t port_id,
                                     const RDMRequest *request,
                                     RDMCallback *on_complete) {
-  vector<std::string> packets;
+  vector<string> packets;
   if (request->CommandClass() == RDMCommand::DISCOVER_COMMAND) {
     on_complete->Run(ola::rdm::RDM_PLUGIN_DISCOVERY_NOT_SUPPORTED,
                      NULL,
@@ -795,13 +669,6 @@ void ArtNetNodeImpl::SendRDMRequest(uint8_t port_id,
   }
 }
 
-
-/*
- * Set the RDM handlers for an Input port
- * @param port_id the id of the port to set the handlers for
- * @param tod_callback the callback to be invoked when a ArtTod message is received,
- *   and the RDM process isn't running.
- */
 bool ArtNetNodeImpl::SetUnsolicitedUIDSetHandler(
     uint8_t port_id,
     ola::Callback1<void, const ola::rdm::UIDSet&> *tod_callback) {
@@ -811,11 +678,6 @@ bool ArtNetNodeImpl::SetUnsolicitedUIDSetHandler(
   return port;
 }
 
-
-/**
- * Populate the vector with a list of IP addresses that are known to be
- * listening for the universe that this port is sending
- */
 void ArtNetNodeImpl::GetSubscribedNodes(
     uint8_t port_id,
     vector<IPV4Address> *node_addresses) {
@@ -834,13 +696,6 @@ void ArtNetNodeImpl::GetSubscribedNodes(
   }
 }
 
-
-/*
- * Set the closure to be called when we receive data for this universe.
- * @param universe the universe to register the handler for
- * @param handler the Callback0 to call when there is data for this universe.
- * Ownership of the closure is transferred to the node.
- */
 bool ArtNetNodeImpl::SetDMXHandler(uint8_t port_id,
                                    DmxBuffer *buffer,
                                    Callback0<void> *on_data) {
@@ -855,10 +710,6 @@ bool ArtNetNodeImpl::SetDMXHandler(uint8_t port_id,
   return true;
 }
 
-
-/*
- * Send an set of UIDs in one of more ArtTod packets
- */
 bool ArtNetNodeImpl::SendTod(uint8_t port_id, const UIDSet &uid_set) {
   OutputPort *port = GetEnabledOutputPort(port_id, "ArtTodData");
   if (!port)
@@ -908,10 +759,6 @@ bool ArtNetNodeImpl::SendTod(uint8_t port_id, const UIDSet &uid_set) {
   return true;
 }
 
-
-/*
- * Set the RDM handlers for an Output port
- */
 bool ArtNetNodeImpl::SetOutputPortRDMHandlers(
     uint8_t port_id,
     ola::Callback0<void> *on_discover,
@@ -933,10 +780,6 @@ bool ArtNetNodeImpl::SetOutputPortRDMHandlers(
   return true;
 }
 
-
-/**
- * Send a timecode packet
- */
 bool ArtNetNodeImpl::SendTimeCode(const ola::timecode::TimeCode &timecode) {
   artnet_packet packet;
   PopulatePacketHeader(&packet, ARTNET_TIME_CODE);
@@ -957,9 +800,6 @@ bool ArtNetNodeImpl::SendTimeCode(const ola::timecode::TimeCode &timecode) {
   return true;
 }
 
-/*
- * Called when there is data on this socket
- */
 void ArtNetNodeImpl::SocketReady() {
   artnet_packet packet;
   ssize_t packet_size = sizeof(packet);
@@ -973,11 +813,6 @@ void ArtNetNodeImpl::SocketReady() {
   HandlePacket(source.Host(), packet, packet_size);
 }
 
-
-/*
- * Send an ArtPoll if we're both running and not in configuration mode.
- * If we're in configuration mode this sets m_artpoll_required instead.
- */
 bool ArtNetNodeImpl::SendPollIfAllowed() {
   if (!m_running)
     return true;
@@ -990,12 +825,6 @@ bool ArtNetNodeImpl::SendPollIfAllowed() {
   return true;
 }
 
-
-/*
- * Send an ArtPollReply if we're both running and m_send_reply_on_change is
- * true. If we're in configuration mode, this sets m_artpollreply_required
- * instead of sending.
- */
 bool ArtNetNodeImpl::SendPollReplyIfRequired() {
   if (m_running && m_send_reply_on_change) {
     if (m_in_configuration_mode) {
@@ -1008,9 +837,6 @@ bool ArtNetNodeImpl::SendPollReplyIfRequired() {
   return true;
 }
 
-/*
- * Send an ArtPollReply message
- */
 bool ArtNetNodeImpl::SendPollReply(const IPV4Address &destination) {
   artnet_packet packet;
   PopulatePacketHeader(&packet, ARTNET_REPLY);
@@ -1059,10 +885,6 @@ bool ArtNetNodeImpl::SendPollReply(const IPV4Address &destination) {
   return true;
 }
 
-
-/*
- * Send an IPProgReply
- */
 bool ArtNetNodeImpl::SendIPReply(const IPV4Address &destination) {
   artnet_packet packet;
   PopulatePacketHeader(&packet, ARTNET_REPLY);
@@ -1080,10 +902,6 @@ bool ArtNetNodeImpl::SendIPReply(const IPV4Address &destination) {
   return true;
 }
 
-
-/*
- * Handle a artnet packet
- */
 void ArtNetNodeImpl::HandlePacket(const IPV4Address &source_address,
                                   const artnet_packet &packet,
                                   unsigned int packet_size) {
@@ -1147,10 +965,6 @@ void ArtNetNodeImpl::HandlePacket(const IPV4Address &source_address,
   }
 }
 
-
-/*
- * Handle an ArtPoll packet
- */
 void ArtNetNodeImpl::HandlePollPacket(const IPV4Address &source_address,
                                       const artnet_poll_t &packet,
                                       unsigned int packet_size) {
@@ -1166,10 +980,6 @@ void ArtNetNodeImpl::HandlePollPacket(const IPV4Address &source_address,
   (void) source_address;
 }
 
-
-/*
- * Handle an ArtPollReply packet
- */
 void ArtNetNodeImpl::HandleReplyPacket(const IPV4Address &source_address,
                                        const artnet_reply_t &packet,
                                        unsigned int packet_size) {
@@ -1214,10 +1024,6 @@ void ArtNetNodeImpl::HandleReplyPacket(const IPV4Address &source_address,
   }
 }
 
-
-/*
- * Handle a DMX Data packet, this takes care of the merging
- */
 void ArtNetNodeImpl::HandleDataPacket(const IPV4Address &source_address,
                                       const artnet_dmx_t &packet,
                                       unsigned int packet_size) {
@@ -1256,10 +1062,6 @@ void ArtNetNodeImpl::HandleDataPacket(const IPV4Address &source_address,
   }
 }
 
-
-/*
- * Handle a TOD Request packet
- */
 void ArtNetNodeImpl::HandleTodRequest(const IPV4Address &source_address,
                                       const artnet_todrequest_t &packet,
                                       unsigned int packet_size) {
@@ -1309,10 +1111,6 @@ void ArtNetNodeImpl::HandleTodRequest(const IPV4Address &source_address,
   }
 }
 
-
-/*
- * Handle a TOD data packet
- */
 void ArtNetNodeImpl::HandleTodData(const IPV4Address &source_address,
                                    const artnet_toddata_t &packet,
                                    unsigned int packet_size) {
@@ -1351,10 +1149,6 @@ void ArtNetNodeImpl::HandleTodData(const IPV4Address &source_address,
   }
 }
 
-
-/*
- * Handle a TOD Control packet
- */
 void ArtNetNodeImpl::HandleTodControl(const IPV4Address &source_address,
                                       const artnet_todcontrol_t &packet,
                                       unsigned int packet_size) {
@@ -1385,10 +1179,6 @@ void ArtNetNodeImpl::HandleTodControl(const IPV4Address &source_address,
   }
 }
 
-
-/*
- * Handle an RDM packet
- */
 void ArtNetNodeImpl::HandleRdm(const IPV4Address &source_address,
                                const artnet_rdm_t &packet,
                                unsigned int packet_size) {
@@ -1452,17 +1242,13 @@ void ArtNetNodeImpl::HandleRdm(const IPV4Address &source_address,
   }
 }
 
-
-/**
- * Handle the completion of a request for an Output port
- */
 void ArtNetNodeImpl::RDMRequestCompletion(
     IPV4Address destination,
     uint8_t port_id,
     uint8_t universe_address,
     ola::rdm::rdm_response_code code,
     const RDMResponse *raw_response,
-    const vector<std::string>&) {
+    const vector<string>&) {
   auto_ptr<const RDMResponse> response(raw_response);
   OutputPort *port = GetEnabledOutputPort(port_id, "ArtRDM");
   if (!port)
@@ -1485,15 +1271,6 @@ void ArtNetNodeImpl::RDMRequestCompletion(
   }
 }
 
-
-/**
- * Handle an RDM response.
- * <rant>
- * ArtNet as a protocol is broken, the nodes don't buffer ACK_OVERFLOW messages
- * so if another GET/SET message arrives from *any* controller the ACK_OVERFLOW
- * session will be reset, possibly causing the controller to spin in a loop.
- * </rant>
- */
 void ArtNetNodeImpl::HandleRDMResponse(InputPort *port,
                                        const string &response_data,
                                        const IPV4Address &source_address) {
@@ -1575,10 +1352,6 @@ void ArtNetNodeImpl::HandleRDMResponse(InputPort *port,
   callback->Run(ola::rdm::RDM_COMPLETED_OK, response.release(), packets);
 }
 
-
-/**
- * Handle an IP Program message.
- */
 void ArtNetNodeImpl::HandleIPProgram(const IPV4Address &source_address,
                                      const artnet_ip_prog_t &packet,
                                      unsigned int packet_size) {
@@ -1593,22 +1366,12 @@ void ArtNetNodeImpl::HandleIPProgram(const IPV4Address &source_address,
            << "configuration";
 }
 
-/*
- * Fill in the header for a packet
- */
 void ArtNetNodeImpl::PopulatePacketHeader(artnet_packet *packet,
                                           uint16_t op_code) {
   strncpy(reinterpret_cast<char*>(packet->id), ARTNET_ID, sizeof(packet->id));
   packet->op_code = HostToLittleEndian(op_code);
 }
 
-
-/*
- * Send an ArtNet packet
- * @param packet
- * @param size the size of the packet, excluding the header portion
- * @param destination where to send the packet to
- */
 bool ArtNetNodeImpl::SendPacket(const artnet_packet &packet,
                                 unsigned int size,
                                 const IPV4Address &ip_destination) {
@@ -1625,11 +1388,6 @@ bool ArtNetNodeImpl::SendPacket(const artnet_packet &packet,
   return true;
 }
 
-
-/**
- * Timeout a pending RDM request
- * @param port_id the id of the port to timeout.
- */
 void ArtNetNodeImpl::TimeoutRDMRequest(InputPort *port) {
   OLA_INFO << "RDM Request timed out.";
   port->rdm_send_timeout = ola::thread::INVALID_TIMEOUT;
@@ -1637,14 +1395,10 @@ void ArtNetNodeImpl::TimeoutRDMRequest(InputPort *port) {
   port->pending_request = NULL;
   ola::rdm::RDMCallback *callback = port->rdm_request_callback;
   port->rdm_request_callback = NULL;
-  vector<std::string> packets;
+  vector<string> packets;
   callback->Run(ola::rdm::RDM_TIMEOUT, NULL, packets);
 }
 
-
-/*
- * Send a generic ArtRdm message
- */
 bool ArtNetNodeImpl::SendRDMCommand(const RDMCommand &command,
                                     const IPV4Address &destination,
                                     uint8_t universe) {
@@ -1665,10 +1419,6 @@ bool ArtNetNodeImpl::SendRDMCommand(const RDMCommand &command,
   return SendPacket(packet, packet_size, destination);
 }
 
-
-/*
- * Update a port from a source, merging if necessary
- */
 void ArtNetNodeImpl::UpdatePortFromSource(OutputPort *port,
                                           const DMXSource &source) {
   TimeStamp merge_time_threshold = (
@@ -1742,10 +1492,6 @@ void ArtNetNodeImpl::UpdatePortFromSource(OutputPort *port,
   port->on_data->Run();
 }
 
-
-/*
- * Check the version number of a incoming packet
- */
 bool ArtNetNodeImpl::CheckPacketVersion(const IPV4Address &source_address,
                                         const string &packet_type,
                                         uint16_t version) {
@@ -1757,10 +1503,6 @@ bool ArtNetNodeImpl::CheckPacketVersion(const IPV4Address &source_address,
   return true;
 }
 
-
-/*
- * Check the size of an incoming packet
- */
 bool ArtNetNodeImpl::CheckPacketSize(const IPV4Address &source_address,
                                      const string &packet_type,
                                      unsigned int actual_size,
@@ -1774,10 +1516,6 @@ bool ArtNetNodeImpl::CheckPacketSize(const IPV4Address &source_address,
   return true;
 }
 
-
-/**
- * Lookup an InputPort by id, if the id is invalid, we return NULL.
- */
 ArtNetNodeImpl::InputPort *ArtNetNodeImpl::GetInputPort(uint8_t port_id,
                                                         bool warn) {
   if (port_id >= m_input_ports.size()) {
@@ -1790,10 +1528,6 @@ ArtNetNodeImpl::InputPort *ArtNetNodeImpl::GetInputPort(uint8_t port_id,
   return m_input_ports[port_id];
 }
 
-
-/**
- * A const version of GetInputPort();
- */
 const ArtNetNodeImpl::InputPort *ArtNetNodeImpl::GetInputPort(
     uint8_t port_id) const {
   if (port_id >= m_input_ports.size()) {
@@ -1804,10 +1538,6 @@ const ArtNetNodeImpl::InputPort *ArtNetNodeImpl::GetInputPort(
   return m_input_ports[port_id];
 }
 
-
-/*
- * Similar to GetInputPort, but this also confirms the port is enabled.
- */
 ArtNetNodeImpl::InputPort *ArtNetNodeImpl::GetEnabledInputPort(
     uint8_t port_id,
     const string &action) {
@@ -1821,10 +1551,6 @@ ArtNetNodeImpl::InputPort *ArtNetNodeImpl::GetEnabledInputPort(
   return ok ? port : NULL;
 }
 
-
-/**
- * Lookup an OutputPort by id, if the id is invalid, we return NULL.
- */
 ArtNetNodeImpl::OutputPort *ArtNetNodeImpl::GetOutputPort(uint8_t port_id) {
   if (port_id >= ARTNET_MAX_PORTS) {
     OLA_WARN << "Port index of out bounds: " <<
@@ -1834,10 +1560,6 @@ ArtNetNodeImpl::OutputPort *ArtNetNodeImpl::GetOutputPort(uint8_t port_id) {
   return &m_output_ports[port_id];
 }
 
-
-/**
- * A const version of GetOutputPort();
- */
 const ArtNetNodeImpl::OutputPort *ArtNetNodeImpl::GetOutputPort(
     uint8_t port_id) const {
   if (port_id >= ARTNET_MAX_PORTS) {
@@ -1848,10 +1570,6 @@ const ArtNetNodeImpl::OutputPort *ArtNetNodeImpl::GetOutputPort(
   return &m_output_ports[port_id];
 }
 
-
-/*
- * Similar to GetOutputPort, but this also confirms the port is enabled.
- */
 ArtNetNodeImpl::OutputPort *ArtNetNodeImpl::GetEnabledOutputPort(
     uint8_t port_id,
     const string &action) {
@@ -1865,10 +1583,6 @@ ArtNetNodeImpl::OutputPort *ArtNetNodeImpl::GetEnabledOutputPort(
   return ok ? port : NULL;
 }
 
-
-/*
- * Setup the networking components.
- */
 bool ArtNetNodeImpl::InitNetwork() {
   if (!m_socket->Init()) {
     OLA_WARN << "Socket init failed";
@@ -1890,10 +1604,6 @@ bool ArtNetNodeImpl::InitNetwork() {
   return true;
 }
 
-
-/*
- * Update a port with a new TOD list
- */
 void ArtNetNodeImpl::UpdatePortFromTodPacket(InputPort *port,
                                              const IPV4Address &source_address,
                                              const artnet_toddata_t &packet,
@@ -1959,11 +1669,6 @@ void ArtNetNodeImpl::UpdatePortFromTodPacket(InputPort *port,
     port->RunTodCallback();
 }
 
-
-/*
- * Start the discovery process, this puts the port into discovery mode and
- * sets up the callback.
- */
 bool ArtNetNodeImpl::StartDiscoveryProcess(InputPort *port,
                                            RDMDiscoveryCallback *callback) {
   if (port->discovery_callback) {
@@ -1994,10 +1699,6 @@ bool ArtNetNodeImpl::StartDiscoveryProcess(InputPort *port,
   return true;
 }
 
-
-/*
- * Called when the discovery process times out.
- */
 void ArtNetNodeImpl::ReleaseDiscoveryLock(InputPort *port) {
   OLA_INFO << "Artnet RDM discovery complete";
   port->discovery_timeout = ola::thread::INVALID_TIMEOUT;
@@ -2016,10 +1717,6 @@ void ArtNetNodeImpl::ReleaseDiscoveryLock(InputPort *port) {
   port->RunDiscoveryCallback();
 }
 
-
-/**
- * DmxTriWidget Constructor
- */
 ArtNetNode::ArtNetNode(const ola::network::Interface &iface,
                        ola::io::SelectServerInterface *ss,
                        const ArtNetNodeOptions &options,
@@ -2040,10 +1737,6 @@ ArtNetNode::~ArtNetNode() {
   STLDeleteElements(&m_wrappers);
 }
 
-
-/**
- * Trigger full discovery for a port
- */
 void ArtNetNode::RunFullDiscovery(uint8_t port_id,
                                   RDMDiscoveryCallback *callback) {
   if (!CheckInputPortId(port_id)) {
@@ -2054,10 +1747,6 @@ void ArtNetNode::RunFullDiscovery(uint8_t port_id,
   }
 }
 
-
-/**
- * Trigger incremental discovery for a port.
- */
 void ArtNetNode::RunIncrementalDiscovery(uint8_t port_id,
                                          RDMDiscoveryCallback *callback) {
   if (!CheckInputPortId(port_id)) {
@@ -2068,14 +1757,10 @@ void ArtNetNode::RunIncrementalDiscovery(uint8_t port_id,
   }
 }
 
-
-/**
- * Send a RDM request by passing it though the Queuing Controller
- */
 void ArtNetNode::SendRDMRequest(uint8_t port_id, const RDMRequest *request,
                                 ola::rdm::RDMCallback *on_complete) {
   if (!CheckInputPortId(port_id)) {
-    vector<std::string> packets;
+    vector<string> packets;
     on_complete->Run(ola::rdm::RDM_FAILED_TO_SEND, NULL, packets);
     delete request;
   } else {
@@ -2083,11 +1768,6 @@ void ArtNetNode::SendRDMRequest(uint8_t port_id, const RDMRequest *request,
   }
 }
 
-
-/**
- * Check that the port_id is a valid input port.
- * @return true if the port id is valid, false otherwise
- */
 bool ArtNetNode::CheckInputPortId(uint8_t port_id) {
   if (port_id >= m_controllers.size()) {
     OLA_WARN << "Port index of out bounds: " << static_cast<int>(port_id)
