@@ -34,13 +34,14 @@ namespace ola {
 namespace plugin {
 namespace espnet {
 
-using std::map;
 using ola::network::HostToNetwork;
 using ola::network::IPV4Address;
 using ola::network::IPV4SocketAddress;
 using ola::network::NetworkToHost;
 using ola::network::UDPSocket;
 using ola::Callback0;
+using std::map;
+using std::string;
 
 const char EspNetNode::NODE_NAME[] = "OLA Node";
 
@@ -49,7 +50,7 @@ const char EspNetNode::NODE_NAME[] = "OLA Node";
  * @param ip_address the IP address to prefer to listen on, if NULL we choose
  * one.
  */
-EspNetNode::EspNetNode(const std::string &ip_address)
+EspNetNode::EspNetNode(const string &ip_address)
     : m_running(false),
       m_options(DEFAULT_OPTIONS),
       m_tos(DEFAULT_TOS),
