@@ -22,8 +22,8 @@
 #include <Winsock2.h>
 #endif
 
-#include <ola/BaseTypes.h>
 #include <ola/Callback.h>
+#include <ola/Constants.h>
 #include <ola/ExportMap.h>
 #include <ola/Logging.h>
 #include <ola/StringUtils.h>
