@@ -32,7 +32,7 @@
 #include <string>
 #include <vector>
 #include "ola/base/Array.h"
-#include "ola/BaseTypes.h"
+#include "ola/Constants.h"
 #include "ola/Logging.h"
 #include "ola/file/Util.h"
 #include "ola/network/NetworkUtils.h"
@@ -72,6 +72,7 @@ using ola::rdm::UIDSet;
 using std::auto_ptr;
 using std::min;
 using std::string;
+using std::vector;
 
 const uint16_t SPIOutput::SPI_DELAY = 0;
 const uint8_t SPIOutput::SPI_BITS_PER_WORD = 8;
@@ -472,7 +473,7 @@ const RDMResponse *SPIOutput::GetProductDetailList(
     const RDMRequest *request) {
   // Shortcut for only one item in the vector
   return ResponderHelper::GetProductDetailList(request,
-    std::vector<ola::rdm::rdm_product_detail>
+    vector<ola::rdm::rdm_product_detail>
         (1, ola::rdm::PRODUCT_DETAIL_LED));
 }
 
@@ -539,7 +540,7 @@ const RDMResponse *SPIOutput::SetIdentify(const RDMRequest *request) {
         m_identify_mode ? "on" : "off");
     DmxBuffer identify_buffer;
     if (m_identify_mode) {
-      identify_buffer.SetRangeToValue(0, DMX_MAX_CHANNEL_VALUE,
+      identify_buffer.SetRangeToValue(0, DMX_MAX_SLOT_VALUE,
                                       DMX_UNIVERSE_SIZE);
     } else {
       identify_buffer.Blackout();
