@@ -33,26 +33,28 @@ namespace spi {
 
 class SPIOutputPort: public BasicOutputPort {
  public:
-    SPIOutputPort(SPIDevice *parent, class SPIBackendInterface *backend,
-                  const ola::rdm::UID &uid, const SPIOutput::Options &options);
-    ~SPIOutputPort() {}
+  SPIOutputPort(SPIDevice *parent, class SPIBackendInterface *backend,
+                const ola::rdm::UID &uid, const SPIOutput::Options &options);
+  ~SPIOutputPort() {}
 
-    uint8_t GetPersonality() const;
-    bool SetPersonality(uint16_t personality);
-    uint16_t GetStartAddress() const;
-    bool SetStartAddress(uint16_t start_address);
-    unsigned int PixelCount() const;
+  std::string GetDeviceLabel() const;
+  bool SetDeviceLabel(const std::string &device_label);
+  uint8_t GetPersonality() const;
+  bool SetPersonality(uint16_t personality);
+  uint16_t GetStartAddress() const;
+  bool SetStartAddress(uint16_t start_address);
+  unsigned int PixelCount() const;
 
-    std::string Description() const;
-    bool WriteDMX(const DmxBuffer &buffer, uint8_t priority);
+  std::string Description() const;
+  bool WriteDMX(const DmxBuffer &buffer, uint8_t priority);
 
-    void RunFullDiscovery(ola::rdm::RDMDiscoveryCallback *callback);
-    void RunIncrementalDiscovery(ola::rdm::RDMDiscoveryCallback *callback);
-    void SendRDMRequest(const ola::rdm::RDMRequest *request,
-                        ola::rdm::RDMCallback *callback);
+  void RunFullDiscovery(ola::rdm::RDMDiscoveryCallback *callback);
+  void RunIncrementalDiscovery(ola::rdm::RDMDiscoveryCallback *callback);
+  void SendRDMRequest(const ola::rdm::RDMRequest *request,
+                      ola::rdm::RDMCallback *callback);
 
  private:
-    SPIOutput m_spi_output;
+  SPIOutput m_spi_output;
 };
 }  // namespace spi
 }  // namespace plugin
