@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * SunliteDevice.h
  * Interface for the Sunlite device
@@ -34,15 +34,15 @@ namespace usbdmx {
  */
 class SunliteDevice: public UsbDevice {
  public:
-    SunliteDevice(ola::AbstractPlugin *owner,
-                  libusb_device *usb_device):
-        UsbDevice(owner, "Sunlite USB Device", usb_device) {
-    }
+  SunliteDevice(ola::AbstractPlugin *owner,
+                libusb_device *usb_device)
+      : UsbDevice(owner, "Sunlite USB Device", usb_device) {
+  }
 
-    std::string DeviceId() const { return "usbdmx2"; }
+  std::string DeviceId() const { return "usbdmx2"; }
 
  protected:
-    bool StartHook();
+  bool StartHook();
 };
 }  // namespace usbdmx
 }  // namespace plugin
