@@ -19,7 +19,7 @@
  */
 
 #include <string.h>
-#include "ola/BaseTypes.h"
+#include "ola/Constants.h"
 #include "ola/Logging.h"
 #include "plugins/usbpro/BaseRobeWidget.h"
 
