@@ -30,7 +30,6 @@
 #include <ola/network/NetworkUtils.h>
 #include <ola/network/Socket.h>
 #include <ola/network/SocketAddress.h>
-#include <ola/network/TCPSocketFactory.h>
 
 #include <iostream>
 #include <map>
@@ -50,6 +49,10 @@ using std::string;
 
 namespace ola {
 
+namespace rpc {
+class RpcServer;
+}
+
 namespace http {
 class OlaHTTPServer;
 }
@@ -134,8 +137,6 @@ class SLPDaemon {
                                const URLEntries &urls);
     };
 
-    typedef vector<class ConnectedClient*> DisconnectedClients;
-
     ola::Clock m_clock;
     ola::io::SelectServer m_ss;
     SLPServer m_slp_server;
@@ -143,13 +144,9 @@ class SLPDaemon {
 
     // RPC members
     const uint16_t m_rpc_port;
-    ola::network::TCPSocketFactory m_rpc_socket_factory;
-    ola::network::TCPAcceptingSocket m_rpc_accept_socket;
-    auto_ptr<ola::network::IPV4SocketAddress> m_multicast_endpoint;
-    auto_ptr<SLPServiceImpl> m_service_impl;
-    // maps fd to ConnectedClient structure
-    map<ola::io::DescriptorHandle, class ConnectedClient*> m_connected_clients;
-    DisconnectedClients m_disconnected_clients;
+    std::auto_ptr<ola::network::IPV4SocketAddress> m_multicast_endpoint;
+    std::auto_ptr<SLPServiceImpl> m_service_impl;
+    std::auto_ptr<ola::rpc::RpcServer> m_rpc_server;
 
     // The ExportMap & HTTPServer
     ola::ExportMap *m_export_map;
@@ -158,11 +155,6 @@ class SLPDaemon {
     // Random methods
     void GetDirectoryAgents();
 
-    // RPC methods
-    void NewTCPConnection(TCPSocket *socket);
-    void RPCSocketClosed(ola::io::DescriptorHandle read_descriptor);
-    bool CleanOldClients();
-
     static const uint16_t DEFAULT_SLP_HTTP_PORT;
     static const uint16_t DEFAULT_SLP_RPC_PORT;
 };
