@@ -21,8 +21,8 @@
 #include <config.h>
 #endif
 
-#include <ola/BaseTypes.h>
 #include <ola/Callback.h>
+#include <ola/Constants.h>
 #include <ola/Logging.h>
 #include <ola/StringUtils.h>
 #include <ola/io/BigEndianStream.h>
@@ -33,7 +33,6 @@
 #include <ola/network/NetworkUtils.h>
 #include <ola/network/Socket.h>
 #include <ola/network/SocketAddress.h>
-#include <ola/network/TCPSocketFactory.h>
 #include <ola/stl/STLUtils.h>
 
 #include <algorithm>
